@@ -1,38 +1,38 @@
 import {expectType, expectAssignable} from 'tsd';
-import mapObject = require('./index.js');
+import mapObject, {Options, mapObjectSkip} from './index.js';
 
-const options: mapObject.Options = {};
+const options: Options = {}; // eslint-disable-line @typescript-eslint/no-unused-vars
 
 const newObject = mapObject({foo: 'bar'}, (key, value) => [value, key]);
-expectType<{[key: string]: 'foo'}>(newObject);
+expectType<Record<string, 'foo'>>(newObject);
 expectType<'foo'>(newObject.bar);
 
 const object = mapObject({foo: 'bar'}, (key, value) => [value, key], {
-	target: {baz: 'baz'}
+	target: {baz: 'baz'},
 });
-expectType<{baz: string} & {[x: string]: 'foo'}>(object);
+expectType<{baz: string} & Record<string, 'foo'>>(object);
 expectType<'foo'>(object.bar);
 expectType<string>(object.baz);
 
 const object1 = mapObject({foo: 'bar'}, (key, value) => [value, key], {
 	target: {baz: 'baz'},
-	deep: false
+	deep: false,
 });
-expectType<{baz: string} & {[x: string]: 'foo'}>(object1);
+expectType<{baz: string} & Record<string, 'foo'>>(object1);
 expectType<'foo'>(object1.bar);
 expectType<string>(object1.baz);
 
 const object2 = mapObject({foo: 'bar'}, (key, value) => [value, key], {
-	deep: true
+	deep: true,
 });
-expectType<{[key: string]: unknown}>(object2);
+expectType<Record<string, unknown>>(object2);
 const object3 = mapObject({foo: 'bar'}, (key, value) => [value, key], {
 	deep: true,
-	target: {bar: 'baz' as const}
+	target: {bar: 'baz' as const},
 });
-expectAssignable<{[key: string]: unknown}>(object3);
+expectAssignable<Record<string, unknown>>(object3);
 expectType<'baz'>(object3.bar);
 
 mapObject({foo: 'bar'}, (key, value) => [value, key, {shouldRecurse: false}]);
 
-mapObject({foo: 'bar'}, () => mapObject.mapObjectSkip);
+mapObject({foo: 'bar'}, () => mapObjectSkip);
